-- wTaskNoteFrame.lua: Sep 2010
-- Control and design of the list of notes frame

-- General design is going to be very similar to that of the current Blizzard quest frame
-- A tree in the left-hand pane, with the content of the note in the right-hand pane

-- Left-hand tree headers based on AceDB3 subtables: 
--   "global", "realm", "class", "race", "faction", "factionrealm", etc.
-- Global notes come first in the list, followed by current realm, current faction, current char
-- Probably won't use all of the available subtables, being able to share notes based on:
--   "global", "current realm", "current faction", "current char", "current profile" will be enough.
-- Design question is whether we want to allow one character to access another character's notes (probably yes)
-- If we go with global accessibility, then we only use the "global" level of AceDB, and we end up
-- with a larger amount of data loaded into memory.
--
-- Possible tree design
-- [+]Global
--   [+]Category 1
--     note1
--     note3
--   [+]Category 2
--     note2
--     note4
-- [+]Current Profile
--   [+]Category 1
--     note1
--     note3
--   [+]Category 2
--     note2
--     note4
-- [+]Current Server
--   [+]Category 1
--     note1
--     note3
--   [+]Category 2
--     note2
--     note4
-- [+]Current Character
--   [+]Category 1
--     note1
--     note3
--   [+]Category 2
--     note2
--     note4
-- 
-- As we click on stuff in the left pane, we need to update the right pane to display the contents
-- Buttons: 
--   "New" (new note) 
--   "Delete" (delete selected note) 
--   "Move" (move a note to a different category, functionality might go on the edit frame instead)
--   "Copy" (make a copy of the currently selected note)
-- Note Attributes:
--   "id" (random identifier string/number)
--   "scope"  (global, server, character)
--   "category" (determines where in the tree it appears)
--   "subject" (short subject line)
--   "body" (body, not sure on length limit, probably same as a mail body)
--
-- It will probably make more sense that notes are always in "edit" mode.  In which case
-- we'll mostly just need a "Save" / "Undo" pair of buttons on the right side panel at the bottom.
--
-- Category is going to need a text entry pop-up box if the user clicks "New" next to the category drop-down
--
-- Right-hand pane UI elements:
--
-- Scope: [drop-down w/ global, server, char, default of char]
--   if scope changes, then category also changes to the first category under that scope
-- Category: [drop-down, default of "General"] w/ [New] button
--   if category changes, then we need to move the message in the left-hand list
-- Subject: [text box, same limit as mail message]
--   current limit: 64 characters in mail message subject
-- Body: (unlabled control)
--   current limit: 500 characters in mail body
-- Buttons: [DELETE] [SAVE] [CANCEL]
-- 
-- Left-hand pane UI elements:
-- 
-- Tree view of scope / category / notes
--   sort by current subject line
-- Buttons: [DELETE] [NEW] [COPY]
-- 

-- stub in AceGUI so we can make use of some features
local AceGUI = LibStub("AceGUI-3.0")

-----------------------------------------------------------------------------
-- Create the main frame of the interface (for notes)
-- Look at Auctioneer's SearchMain.lua file: lib.CreateAuctionFrames()
-- We'll probably base our artwork off of Blizzard artwork
function wTaskNote:CreateNoteFrame()
	if wTaskNoteFrame then return end
	
	-- Create the master UI frame for note editing/display
	-- Note: also creates a global variable named wTaskNoteFrame as a side-effect
	local f = CreateFrame("Frame","wTaskNoteFrame",UIParent)
	f:Hide()
	f:SetFrameStrata("BACKGROUND")
	f:SetWidth(800)
	f:SetHeight(400)
	f:SetMovable(true) -- frame is movable
	f:SetResizable(false) -- frame is not resizable (for now)
	f:SetClampedToScreen(true) -- keep our window constrained to the screen
		
	local t = f:CreateTexture(nil,"BACKGROUND")
	t:SetTexture("Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Factions.blp")
	t:SetAllPoints(f)
	f.texture = t

	f:SetPoint("CENTER", UIParent, "CENTER")
	
	-- Hook into the OnShow/OnHide handler for our widget and add some custom
	-- code to the mix (such as playing a sound effect like the quest log does)
	f:SetScript("OnShow",wTaskNoteFrame_OnShow)
	f:SetScript("OnHide",wTaskNoteFrame_OnHide)
	
	-- Note: our frame should initially be hidden and Show() gets called in ToggleNoteFrame
	--f:Show()
	
	
	--wTaskNoteFrame = AceGUI:Create("Frame")
	--wTaskNoteFrame:SetTitle("Example Frame")
	--wTaskNoteFrame:SetStatusText("AceGUI-3.0 Example Container Frame")
	--wTaskNoteFrame:SetWidth(800)
	--wTaskNoteFrame:SetHeight(400)
	--wTaskNoteFrame:SetCallback("OnClose", function(widget) widget:Hide() end)

	-- Setup the left frame and right frame
	--local leftframe = AceGUI:Create("ScrollFrame")
	--wTaskNoteFrame:AddChild(leftframe)
	--local rightframe = AceGUI:Create("ScrollFrame")
	--wTaskNoteFrame:AddChild(rightframe)
	
	-- Applying this layout will cause the first two children to take up half the width and full height
	--wTaskNoteFrame:SetLayout("wTaskNote_Split")

	--local editline = AceGUI:Create("EditBox")
	--editbox:SetLabel("Insert text:")
	--editbox:SetWidth(200)
	--rightframe:AddChild(editbox)
	
	--local editline = AceGUI:Create("EditBox")
	--editbox:SetLabel("Insert text:")
	--editbox:SetWidth(200)
	--rightframe:AddChild(editbox)

end

-----------------------------------------------------------------------------
-- Toggle visibility of the note frame
function wTaskNote:ToggleNoteFrame()
	if not wTaskNoteFrame then wTaskNote:CreateNoteFrame() end
	if wTaskNoteFrame:IsShown() then
		wTaskNoteFrame:Hide()
	else
		wTaskNoteFrame:Show()
	end
end

-----------------------------------------------------------------------------
-- Event that fires when the wTaskNoteFrame is displayed
-- The actual function name doesn't really matter, as long as it matches up
-- with the SetScript() call back where we created the frame.
function wTaskNoteFrame_OnShow(self)
	PlaySound("igQuestLogOpen");
	
	-- DEBUG: walk our database table (and sub-tables)
	wTaskNote:DebugWalkTable(wTaskNote.db, "wTaskNote.db")
end

-----------------------------------------------------------------------------
-- Event that fires when the wTaskNoteFrame is hidden
function wTaskNoteFrame_OnHide(self)
	PlaySound("igQuestLogClose");
end